@@ -1864,3 +1864,406 @@ def cm_wv_enhancement():
 
     cmap = mpl.colors.LinearSegmentedColormap('WV_enhancement', cdict)
     return cmap
+
+
+def cm_RdBufloat(valrange):
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+    # Will define a colortable that keeps zero as white
+    length = max(valrange)-min(valrange)
+    distance = 0 - min(valrange)
+    pct = float(distance)/float(length)
+            
+    RdBufloat_cdict ={'red':((0.00, 0.00, 0.00),
+			             	 (pct, 1.00, 1.00),
+				             (1.00, 1.00, 1.00)),
+		              'green':((0.00, 0.00, 0.00),
+				              (pct, 1.00, 1.00),
+			              	  (1.00, 0.00, 0.00)),
+		              'blue': ((0.00, 1.00, 1.00),
+				               (pct, 1.00, 1.00),
+				               (1.00, 0.00, 0.00))}
+    RdBufloat_coltbl = mpl.colors.LinearSegmentedColormap('RdBufloat_COLTBL',RdBufloat_cdict)
+    return RdBufloat_coltbl
+
+
+def cm_rain1():
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+	rain_cdict ={'red':	((0.00, 0.00, 0.00),
+				(1.00, 0.00, 0.00)),
+		'green':	((0.00, 1.00, 1.00),
+				(1.00, 0.20, 0.20)),
+		'blue':		((0.00, 0.00, 0.00),
+				(1.00, 0.00, 0.00))}
+	rain_coltbl = mpl.colors.LinearSegmentedColormap('RAIN_COLTBL',rain_cdict)
+	return rain_coltbl
+
+
+def cm_snow1():
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+	snow_cdict ={'red':	((0.00, 0.00, 0.00),
+				(1.00, 0.00, 0.00)),
+		'green':	((0.00, 0.00, 0.00),
+				(1.00, 0.00, 0.00)),
+		'blue':		((0.00, 1.00, 1.00),
+				(1.00, 0.20, 0.20))}
+	snow_coltbl = mpl.colors.LinearSegmentedColormap('SNOW_COLTBL',snow_cdict)
+	return snow_coltbl
+
+
+def mixprecip1():
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+	mix_cdict ={'red':	((0.00, 0.20, 0.20),
+				(1.00, 1.00, 1.00)),
+		'green':	((0.00, 0.00, 0.00),
+				(1.00, 0.00, 0.00)),
+		'blue':		((0.00, 0.00, 0.00),
+				(1.00, 0.00, 0.00))}
+	mix_coltbl = mpl.colors.LinearSegmentedColormap('MIX_COLTBL',mix_cdict)
+	return mix_coltbl
+
+
+def cm_grays():
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+	grays_cdict ={'red':	((0.00, 1.00, 1.00),
+				(1.00, 0.05, 0.05)),
+		'green':	((0.00, 1.00, 1.00),
+				(1.00, 0.05, 0.05)),
+		'blue':		((0.00, 1.00, 1.00),
+				(1.00, 0.05, 0.05))}
+	grays_coltbl = mpl.colors.LinearSegmentedColormap('GRAYS_COLTBL',grays_cdict)
+	return grays_coltbl
+
+
+def cm_reflect():
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+    reflect_cdict ={'red':	((0.000, 0.40, 0.40),
+				(0.067, 0.20, 0.20),
+				(0.133, 0.00, 0.00),
+				(0.200, 0.00, 0.00),
+				(0.267, 0.00, 0.00),
+				(0.333, 0.00, 0.00),
+				(0.400, 1.00, 1.00),
+				(0.467, 1.00, 1.00),
+				(0.533, 1.00, 1.00),
+				(0.600, 1.00, 1.00),
+				(0.667, 0.80, 0.80),
+				(0.733, 0.60, 0.60),
+				(0.800, 1.00, 1.00),
+				(0.867, 0.60, 0.60),
+				(0.933, 1.00, 1.00),
+				(1.000, 0.00, 0.00)),
+		'green':	((0.000, 1.00, 1.00),
+				(0.067, 0.60, 0.60),
+				(0.133, 0.00, 0.00),
+				(0.200, 1.00, 1.00),
+				(0.267, 0.80, 0.80),
+				(0.333, 0.60, 0.60),
+				(0.400, 1.00, 1.00),
+				(0.467, 0.80, 0.80),
+				(0.533, 0.40, 0.40),
+				(0.600, 0.00, 0.00),
+				(0.667, 0.20, 0.20),
+				(0.733, 0.00, 0.00),
+				(0.800, 0.00, 0.00),
+				(0.867, 0.20, 0.20),
+				(0.933, 1.00, 1.00),
+				(1.000, 1.00, 1.00)),
+		'blue':		((0.000, 1.00, 1.00),
+				(0.067, 1.00, 1.00),
+				(0.133, 1.00, 1.00),
+				(0.200, 0.00, 0.00),
+				(0.267, 0.00, 0.00),
+				(0.333, 0.00, 0.00),
+				(0.400, 0.00, 0.00),
+				(0.467, 0.00, 0.00),
+				(0.533, 0.00, 0.00),
+				(0.600, 0.00, 0.00),
+				(0.667, 0.00, 0.00),
+				(0.733, 0.00, 0.00),
+				(0.800, 1.00, 1.00),
+				(0.867, 0.80, 0.80),
+				(0.933, 1.00, 1.00),
+				(1.000, 1.00, 1.00))}
+    reflect_coltbl = mpl.colors.LinearSegmentedColormap('REFLECT_COLTBL',reflect_cdict)
+    return reflect_coltbl
+
+
+def cm_bw_irsat():
+    # https://github.com/lmadaus/old_wrf_plotting_scripts/blob/master/coltbls.py
+	bw_irsat_cdict ={'red':	((0.000, 1.000, 1.000),
+				(1.000, 0.000, 0.000)),
+		'green':	((0.000, 1.000, 1.000),
+				(1.000, 0.000, 0.000)),
+		'blue':		((0.000, 1.000, 1.000),
+				(1.000, 0.000, 0.000))}
+	bw_irsat_coltbl = mpl.colors.LinearSegmentedColormap('BW_IRSAT_COLTBL',bw_irsat_cdict)
+	return bw_irsat_coltbl
+
+
+def cm_PkBlfloat(datarange):
+   distance = max(datarange)-min(datarange)
+   zeroloc = 0-min(datarange)
+   pct = float(zeroloc)/float(distance)
+
+   # Now, rescale the colormap so each value
+   # is scaled to equal that
+   PkBl_data = {'red':   [(0.*pct, 0.1178, 0.1178),(0.015873*pct, 0.195857, 0.195857),
+                        (0.031746*pct, 0.250661, 0.250661),(0.047619*pct, 0.295468, 0.295468),
+                        (0.063492*pct, 0.334324, 0.334324),(0.079365*pct, 0.369112, 0.369112),
+                        (0.095238*pct, 0.400892, 0.400892),(0.111111*pct, 0.430331, 0.430331),
+                        (0.126984*pct, 0.457882, 0.457882),(0.142857*pct, 0.483867, 0.483867),
+                        (0.158730*pct, 0.508525, 0.508525),(0.174603*pct, 0.532042, 0.532042),
+                        (0.190476*pct, 0.554563, 0.554563),(0.206349*pct, 0.576204, 0.576204),
+                        (0.222222*pct, 0.597061, 0.597061),(0.238095*pct, 0.617213, 0.617213),
+                        (0.253968*pct, 0.636729, 0.636729),(0.269841*pct, 0.655663, 0.655663),
+                        (0.285714*pct, 0.674066, 0.674066),(0.301587*pct, 0.691980, 0.691980),
+                        (0.317460*pct, 0.709441, 0.709441),(0.333333*pct, 0.726483, 0.726483),
+                        (0.349206*pct, 0.743134, 0.743134),(0.365079*pct, 0.759421, 0.759421),
+                        (0.380952*pct, 0.766356, 0.766356),(0.396825*pct, 0.773229, 0.773229),
+                        (0.412698*pct, 0.780042, 0.780042),(0.428571*pct, 0.786796, 0.786796),
+                        (0.444444*pct, 0.793492, 0.793492),(0.460317*pct, 0.800132, 0.800132),
+                        (0.476190*pct, 0.806718, 0.806718),(0.492063*pct, 0.813250, 0.813250),
+                        (0.507937*pct, 0.819730, 0.819730),(0.523810*pct, 0.826160, 0.826160),
+                        (0.539683*pct, 0.832539, 0.832539),(0.555556*pct, 0.838870, 0.838870),
+                        (0.571429*pct, 0.845154, 0.845154),(0.587302*pct, 0.851392, 0.851392),
+                        (0.603175*pct, 0.857584, 0.857584),(0.619048*pct, 0.863731, 0.863731),
+                        (0.634921*pct, 0.869835, 0.869835),(0.650794*pct, 0.875897, 0.875897),
+                        (0.666667*pct, 0.881917, 0.881917),(0.682540*pct, 0.887896, 0.887896),
+                        (0.698413*pct, 0.893835, 0.893835),(0.714286*pct, 0.899735, 0.899735),
+                        (0.730159*pct, 0.905597, 0.905597),(0.746032*pct, 0.911421, 0.911421),
+                        (0.761905*pct, 0.917208, 0.917208),(0.777778*pct, 0.922958, 0.922958),
+                        (0.793651*pct, 0.928673, 0.928673),(0.809524*pct, 0.934353, 0.934353),
+                        (0.825397*pct, 0.939999, 0.939999),(0.841270*pct, 0.945611, 0.945611),
+                        (0.857143*pct, 0.951190, 0.951190),(0.873016*pct, 0.956736, 0.956736),
+                        (0.888889*pct, 0.962250, 0.962250),(0.904762*pct, 0.967733, 0.967733),
+                        (0.920635*pct, 0.973185, 0.973185),(0.936508*pct, 0.978607, 0.978607),
+                        (0.952381*pct, 0.983999, 0.983999),(0.968254*pct, 0.989361, 0.989361),
+                        (0.984127*pct, 0.994695, 0.994695),(1.0*pct, 1.0, 1.0),
+                        ((1-pct)*0.125+pct, 0.87058824300765991, 0.87058824300765991), 
+                        ((1-pct)*0.25+pct,0.7764706015586853, 0.7764706015586853), 
+                        ((1-pct)*0.375+pct, 0.61960786581039429, 0.61960786581039429), 
+                        ((1-pct)*0.5+pct, 0.41960784792900085, 0.41960784792900085), 
+                        ((1-pct)*0.625+pct,	0.25882354378700256, 0.25882354378700256), 
+                        ((1-pct)*0.75+pct, 0.12941177189350128, 0.12941177189350128),
+                        ((1-pct)*0.875+pct,	0.031372550874948502, 0.031372550874948502),
+                        (1.0, 0.031372550874948502, 0.031372550874948502)],
+
+              'green': [(0., 0., 0.),(0.015873*pct, 0.102869, 0.102869),
+                        (0.031746*pct, 0.145479, 0.145479),(0.047619*pct, 0.178174, 0.178174),
+                        (0.063492*pct, 0.205738, 0.205738),(0.079365*pct, 0.230022, 0.230022),
+                        (0.095238*pct, 0.251976, 0.251976),(0.111111*pct, 0.272166, 0.272166),
+                        (0.126984*pct, 0.290957, 0.290957),(0.142857*pct, 0.308607, 0.308607),
+                        (0.158730*pct, 0.325300, 0.325300),(0.174603*pct, 0.341178, 0.341178),
+                        (0.190476*pct, 0.356348, 0.356348),(0.206349*pct, 0.370899, 0.370899),
+                        (0.222222*pct, 0.384900, 0.384900),(0.238095*pct, 0.398410, 0.398410),
+                        (0.253968*pct, 0.411476, 0.411476),(0.269841*pct, 0.424139, 0.424139),
+                        (0.285714*pct, 0.436436, 0.436436),(0.301587*pct, 0.448395, 0.448395),
+                        (0.317460*pct, 0.460044, 0.460044),(0.333333*pct, 0.471405, 0.471405),
+                        (0.349206*pct, 0.482498, 0.482498),(0.365079*pct, 0.493342, 0.493342),
+                        (0.380952*pct, 0.517549, 0.517549),(0.396825*pct, 0.540674, 0.540674),
+                        (0.412698*pct, 0.562849, 0.562849),(0.428571*pct, 0.584183, 0.584183),
+                        (0.444444*pct, 0.604765, 0.604765),(0.460317*pct, 0.624669, 0.624669),
+                        (0.476190*pct, 0.643958, 0.643958),(0.492063*pct, 0.662687, 0.662687),
+                        (0.507937*pct, 0.680900, 0.680900),(0.523810*pct, 0.698638, 0.698638),
+                        (0.539683*pct, 0.715937, 0.715937),(0.555556*pct, 0.732828, 0.732828),
+                        (0.571429*pct, 0.749338, 0.749338),(0.587302*pct, 0.765493, 0.765493),
+                        (0.603175*pct, 0.781313, 0.781313),(0.619048*pct, 0.796819, 0.796819),
+                        (0.634921*pct, 0.812029, 0.812029),(0.650794*pct, 0.826960, 0.826960),
+                        (0.666667*pct, 0.841625, 0.841625),(0.682540*pct, 0.856040, 0.856040),
+                        (0.698413*pct, 0.870216, 0.870216),(0.714286*pct, 0.884164, 0.884164),
+                        (0.730159*pct, 0.897896, 0.897896),(0.746032*pct, 0.911421, 0.911421),
+                        (0.761905*pct, 0.917208, 0.917208),(0.777778*pct, 0.922958, 0.922958),
+                        (0.793651*pct, 0.928673, 0.928673),(0.809524*pct, 0.934353, 0.934353),
+                        (0.825397*pct, 0.939999, 0.939999),(0.841270*pct, 0.945611, 0.945611),
+                        (0.857143*pct, 0.951190, 0.951190),(0.873016*pct, 0.956736, 0.956736),
+                        (0.888889*pct, 0.962250, 0.962250),(0.904762*pct, 0.967733, 0.967733),
+                        (0.920635*pct, 0.973185, 0.973185),(0.936508*pct, 0.978607, 0.978607),
+                        (0.952381*pct, 0.983999, 0.983999),(0.968254*pct, 0.989361, 0.989361),
+                        (0.984127*pct, 0.994695, 0.994695),(1.0*pct, 1.0, 1.0), 
+                        ((1-pct)*0.125+pct,	0.92156863212585449, 0.92156863212585449), 
+                        ((1-pct)*0.25+pct, 0.85882353782653809, 0.85882353782653809), 
+                        ((1-pct)*0.375+pct,	0.7921568751335144, 0.7921568751335144), 
+                        ((1-pct)*0.5+pct, 0.68235296010971069, 0.68235296010971069), 
+                        ((1-pct)*0.625+pct,	0.57254904508590698, 0.57254904508590698), 
+                        ((1-pct)*0.75+pct, 0.44313725829124451, 0.44313725829124451), 
+                        ((1-pct)*0.875+pct,	0.31764706969261169, 0.31764706969261169), 
+                        ((1-pct)*1.0+pct, 0.18823529779911041, 0.18823529779911041)],
+
+              'blue':  [(0.*pct, 0., 0.),(0.015873*pct, 0.102869, 0.102869),
+                        (0.031746*pct, 0.145479, 0.145479),(0.047619*pct, 0.178174, 0.178174),
+                        (0.063492*pct, 0.205738, 0.205738),(0.079365*pct, 0.230022, 0.230022),
+                        (0.095238*pct, 0.251976, 0.251976),(0.111111*pct, 0.272166, 0.272166),
+                        (0.126984*pct, 0.290957, 0.290957),(0.142857*pct, 0.308607, 0.308607),
+                        (0.158730*pct, 0.325300, 0.325300),(0.174603*pct, 0.341178, 0.341178),
+                        (0.190476*pct, 0.356348, 0.356348),(0.206349*pct, 0.370899, 0.370899),
+                        (0.222222*pct, 0.384900, 0.384900),(0.238095*pct, 0.398410, 0.398410),
+                        (0.253968*pct, 0.411476, 0.411476),(0.269841*pct, 0.424139, 0.424139),
+                        (0.285714*pct, 0.436436, 0.436436),(0.301587*pct, 0.448395, 0.448395),
+                        (0.317460*pct, 0.460044, 0.460044),(0.333333*pct, 0.471405, 0.471405),
+                        (0.349206*pct, 0.482498, 0.482498),(0.365079*pct, 0.493342, 0.493342),
+                        (0.380952*pct, 0.503953, 0.503953),(0.396825*pct, 0.514344, 0.514344),
+                        (0.412698*pct, 0.524531, 0.524531),(0.428571*pct, 0.534522, 0.534522),
+                        (0.444444*pct, 0.544331, 0.544331),(0.460317*pct, 0.553966, 0.553966),
+                        (0.476190*pct, 0.563436, 0.563436),(0.492063*pct, 0.572750, 0.572750),
+                        (0.507937*pct, 0.581914, 0.581914),(0.523810*pct, 0.590937, 0.590937),
+                        (0.539683*pct, 0.599824, 0.599824),(0.555556*pct, 0.608581, 0.608581),
+                        (0.571429*pct, 0.617213, 0.617213),(0.587302*pct, 0.625727, 0.625727),
+                        (0.603175*pct, 0.634126, 0.634126),(0.619048*pct, 0.642416, 0.642416),
+                        (0.634921*pct, 0.650600, 0.650600),(0.650794*pct, 0.658682, 0.658682),
+                        (0.666667*pct, 0.666667, 0.666667),(0.682540*pct, 0.674556, 0.674556),
+                        (0.698413*pct, 0.682355, 0.682355),(0.714286*pct, 0.690066, 0.690066),
+                        (0.730159*pct, 0.697691, 0.697691),(0.746032*pct, 0.705234, 0.705234),
+                        (0.761905*pct, 0.727166, 0.727166),(0.777778*pct, 0.748455, 0.748455),
+                        (0.793651*pct, 0.769156, 0.769156),(0.809524*pct, 0.789314, 0.789314),
+                        (0.825397*pct, 0.808969, 0.808969),(0.841270*pct, 0.828159, 0.828159),
+                        (0.857143*pct, 0.846913, 0.846913),(0.873016*pct, 0.865261, 0.865261),
+                        (0.888889*pct, 0.883229, 0.883229),(0.904762*pct, 0.900837, 0.900837),
+                        (0.920635*pct, 0.918109, 0.918109),(0.936508*pct, 0.935061, 0.935061),
+                        (0.952381*pct, 0.951711, 0.951711),(0.968254*pct, 0.968075, 0.968075),
+                        (0.984127*pct, 0.984167, 0.984167),(1.0*pct, 1.0, 1.0),
+                        ((1-pct)*0.125+pct, 0.9686274528503418, 0.9686274528503418), 
+                        ((1-pct)*0.25+pct, 0.93725490570068359, 0.93725490570068359),
+                        ((1-pct)*0.375+pct, 0.88235294818878174, 0.88235294818878174),
+                        ((1-pct)*0.5+pct, 0.83921569585800171, 0.83921569585800171),
+                        ((1-pct)*0.625+pct, 0.7764706015586853,	0.7764706015586853),
+                        ((1-pct)*0.75+pct, 0.70980393886566162, 0.70980393886566162),
+                        ((1-pct)*0.875+pct, 0.61176472902297974, 0.61176472902297974),
+                        (1.0, 0.41960784792900085, 0.41960784792900085)]}
+
+   PkBl_coltbl = mpl.colors.LinearSegmentedColormap('PKBL_COLTBL',PkBl_data)
+   return PkBl_coltbl
+
+
+def cm_PuRdBlfloat(datarange):
+   distance = max(datarange)-min(datarange)
+   zeroloc = 0-min(datarange)
+   pct = float(zeroloc)/float(distance)
+
+   PuRdBl_data = {'blue': [
+			(0.0*pct, 0.12156862765550613,0.12156862765550613),
+			(0.125*pct,0.26274511218070984, 0.26274511218070984), 
+			(0.25*pct,0.33725491166114807, 0.33725491166114807), 
+			(0.375*pct, 0.54117649793624878, 0.54117649793624878), 
+			(0.5*pct, 0.69019609689712524, 0.69019609689712524),
+			(0.625*pct, 0.78039216995239258,0.78039216995239258), 
+			(0.75*pct, 0.85490196943283081,0.85490196943283081), 
+			(0.875*pct, 0.93725490570068359,0.93725490570068359), 
+			(1.0*pct, 0.97647058963775635,0.97647058963775635), 
+			((1-pct)*0.125+pct, 0.9686274528503418,
+			0.9686274528503418), ((1-pct)*0.25+pct, 0.93725490570068359, 0.93725490570068359),
+			((1-pct)*0.375+pct, 0.88235294818878174, 0.88235294818878174), ((1-pct)*0.5+pct,
+			0.83921569585800171, 0.83921569585800171), ((1-pct)*0.625+pct, 0.7764706015586853,
+			0.7764706015586853), ((1-pct)*0.75+pct, 0.70980393886566162, 0.70980393886566162),
+			((1-pct)*0.875+pct, 0.61176472902297974, 0.61176472902297974), (1.0,
+			0.41960784792900085, 0.41960784792900085)],
+
+    		'green': [
+			(0.0*pct, 0.0, 0.0),
+			(0.125*pct, 0.0, 0.0),
+			(0.25*pct, 0.070588238537311554, 0.070588238537311554), 
+			(0.375*pct, 0.16078431904315948, 0.16078431904315948), 
+			(0.5*pct, 0.3960784375667572, 0.3960784375667572), 
+			(0.625*pct, 0.58039218187332153, 0.58039218187332153), 
+			(0.75*pct, 0.72549021244049072, 0.72549021244049072), 
+			(0.875*pct,0.88235294818878174, 0.88235294818878174), 
+			(1.0*pct, 0.95686274766921997, 0.95686274766921997), 
+			((1-pct)*0.125+pct,	0.92156863212585449, 0.92156863212585449), ((1-pct)*0.25+pct,
+    			0.85882353782653809, 0.85882353782653809), ((1-pct)*0.375+pct,
+    			0.7921568751335144, 0.7921568751335144), ((1-pct)*0.5+pct,
+    			0.68235296010971069, 0.68235296010971069), ((1-pct)*0.625+pct,
+    			0.57254904508590698, 0.57254904508590698), ((1-pct)*0.75+pct,
+    			0.44313725829124451, 0.44313725829124451), ((1-pct)*0.875+pct,
+    			0.31764706969261169, 0.31764706969261169), ((1-pct)*1.0+pct,
+    			0.18823529779911041, 0.18823529779911041)],
+
+    		'red': [
+			(0.0*pct, 0.40392157435417175, 0.40392157435417175),
+			(0.125*pct, 0.59607845544815063, 0.59607845544815063), 
+			(0.25*pct, 0.80784314870834351, 0.80784314870834351), 
+			(0.375*pct, 0.90588235855102539, 0.90588235855102539), 
+			(0.5*pct, 0.87450981140136719, 0.87450981140136719), 
+			(0.625*pct, 0.78823530673980713, 0.78823530673980713), 
+			(0.75*pct, 0.83137255907058716, 0.83137255907058716), 
+			(0.875*pct, 0.90588235855102539, 0.90588235855102539), 
+			(1.0*pct, 0.9686274528503418, 0.9686274528503418), 
+			((1-pct)*0.125+pct,
+    			0.87058824300765991, 0.87058824300765991), ((1-pct)*0.25+pct,
+    			0.7764706015586853, 0.7764706015586853), ((1-pct)*0.375+pct,
+    			0.61960786581039429, 0.61960786581039429), ((1-pct)*0.5+pct,
+    			0.41960784792900085, 0.41960784792900085), ((1-pct)*0.625+pct,
+    			0.25882354378700256, 0.25882354378700256), ((1-pct)*0.75+pct,
+    			0.12941177189350128, 0.12941177189350128), ((1-pct)*0.875+pct,
+    			0.031372550874948502, 0.031372550874948502), (1.0,
+    			0.031372550874948502, 0.031372550874948502)]}
+
+   #print PuRdBl_data
+   PuRdBl_coltbl = mpl.colors.LinearSegmentedColormap('PURDBL_COLTBL',PuRdBl_data)
+   return PuRdBl_coltbl
+
+
+def cm_RdBuWH():
+   RdBuWH_data = {'blue': [(0.0, 0.3803921639919281, 0.3803921639919281),
+                           (0.10000000000000002, 0.67450982332229614,
+                            0.67450982332229614),
+                           (0.20000000000000004, 0.76470589637756348,
+                            0.76470589637756348),
+                           (0.29999999999999996, 0.87058824300765991,
+                            0.87058824300765991),
+                           (0.39999999999999998, 0.94117647409439087,
+                            0.94117647409439087),
+                           (0.45, 1.0, 1.0),
+                           (0.55, 1.0, 1.0),
+                           (0.60000000000000002, 0.78039216995239258,
+                            0.78039216995239258),
+                           (0.69999999999999999, 0.50980395078659058,
+                            0.50980395078659058),
+                           (0.80000000000000001, 0.30196079611778259,
+                            0.30196079611778259),
+                           (0.90000000000000001, 0.16862745583057404,
+                            0.16862745583057404),
+                           (1.0, 0.12156862765550613, 0.12156862765550613)],
+
+                  'green': [(0.0, 0.18823529779911041, 0.18823529779911041),
+                            (0.10000000000000002, 0.40000000596046448,
+                             0.40000000596046448),
+                            (0.20000000000000004, 0.57647061347961426,
+                             0.57647061347961426),
+                            (0.29999999999999996, 0.77254903316497803,
+                             0.77254903316497803),
+                            (0.39999999999999998, 0.89803922176361084,
+                             0.89803922176361084),
+                            (0.45, 1.0, 1.0),
+                            (0.55, 1.0, 1.0),
+                            (0.60000000000000002, 0.85882353782653809,
+                             0.85882353782653809),
+                            (0.69999999999999999, 0.64705884456634521,
+                             0.64705884456634521),
+                            (0.80000000000000001, 0.37647059559822083,
+                             0.37647059559822083),
+                            (0.90000000000000001, 0.094117648899555206,
+                             0.094117648899555206),
+                            (1.0, 0.0, 0.0)],
+
+                  'red': [(0.0, 0.019607843831181526, 0.019607843831181526),
+                          (0.10000000000000002, 0.12941177189350128,
+                           0.12941177189350128),
+                          (0.20000000000000004, 0.26274511218070984,
+                           0.26274511218070984),
+                          (0.29999999999999996, 0.57254904508590698,
+                           0.57254904508590698),
+                          (0.39999999999999998, 0.81960785388946533,
+                           0.81960785388946533),
+                          (0.45, 1.0, 1.0),
+                          (0.55, 1.0, 1.0),
+                          (0.60000000000000002, 0.99215686321258545,
+                           0.99215686321258545),
+                          (0.69999999999999999, 0.95686274766921997,
+                           0.95686274766921997),
+                          (0.80000000000000001, 0.83921569585800171,
+                           0.83921569585800171),
+                          (0.90000000000000001, 0.69803923368453979,
+                           0.69803923368453979),
+                          (1.0, 0.40392157435417175, 0.40392157435417175)]}
+   RdBuWH_coltbl = mpl.colors.LinearSegmentedColormap(
+       'RDBUWH_COLTBL', RdBuWH_data)
+   return RdBuWH_coltbl
